syntax = 'proto3';

package canvas;

enum EffectType {
  UNKNOWN_EFFECT = 0;

  LOG = 1;
  ADD_PLAN_COMMAND = 2;

  AUTOCOMPLETE_SEARCH_RESULTS = 3;

  ADD_BANNER_ALERT = 4;
  REMOVE_BANNER_ALERT = 5;

  ORIGINATE_ASSESS_COMMAND = 6;
  EDIT_ASSESS_COMMAND = 7;
  DELETE_ASSESS_COMMAND = 8;
  COMMIT_ASSESS_COMMAND = 9;
  ENTER_IN_ERROR_ASSESS_COMMAND = 10;

  ORIGINATE_DIAGNOSE_COMMAND = 11;
  EDIT_DIAGNOSE_COMMAND = 12;
  DELETE_DIAGNOSE_COMMAND = 13;
  COMMIT_DIAGNOSE_COMMAND = 14;
  ENTER_IN_ERROR_DIAGNOSE_COMMAND = 15;

  ORIGINATE_GOAL_COMMAND = 16;
  EDIT_GOAL_COMMAND = 17;
  DELETE_GOAL_COMMAND = 18;
  COMMIT_GOAL_COMMAND = 19;
  ENTER_IN_ERROR_GOAL_COMMAND = 20;

  ORIGINATE_HPI_COMMAND = 21;
  EDIT_HPI_COMMAND = 22;
  DELETE_HPI_COMMAND = 23;
  COMMIT_HPI_COMMAND = 24;
  ENTER_IN_ERROR_HPI_COMMAND = 25;

  ORIGINATE_MEDICATION_STATEMENT_COMMAND = 26;
  EDIT_MEDICATION_STATEMENT_COMMAND = 27;
  DELETE_MEDICATION_STATEMENT_COMMAND = 28;
  COMMIT_MEDICATION_STATEMENT_COMMAND = 29;
  ENTER_IN_ERROR_MEDICATION_STATEMENT_COMMAND = 30;

  ORIGINATE_PLAN_COMMAND = 31;
  EDIT_PLAN_COMMAND = 32;
  DELETE_PLAN_COMMAND = 33;
  COMMIT_PLAN_COMMAND = 34;
  ENTER_IN_ERROR_PLAN_COMMAND = 35;

  ORIGINATE_PRESCRIBE_COMMAND = 36;
  EDIT_PRESCRIBE_COMMAND = 37;
  DELETE_PRESCRIBE_COMMAND = 38;
  COMMIT_PRESCRIBE_COMMAND = 39;
  ENTER_IN_ERROR_PRESCRIBE_COMMAND = 40;
  SEND_PRESCRIBE_COMMAND = 1305;
  REVIEW_PRESCRIBE_COMMAND = 1309;

  ORIGINATE_QUESTIONNAIRE_COMMAND = 41;
  EDIT_QUESTIONNAIRE_COMMAND = 42;
  DELETE_QUESTIONNAIRE_COMMAND = 43;
  COMMIT_QUESTIONNAIRE_COMMAND = 44;
  ENTER_IN_ERROR_QUESTIONNAIRE_COMMAND = 45;

  ORIGINATE_REASON_FOR_VISIT_COMMAND = 46;
  EDIT_REASON_FOR_VISIT_COMMAND = 47;
  DELETE_REASON_FOR_VISIT_COMMAND = 48;
  COMMIT_REASON_FOR_VISIT_COMMAND = 49;
  ENTER_IN_ERROR_REASON_FOR_VISIT_COMMAND = 50;

  ORIGINATE_STOP_MEDICATION_COMMAND = 51;
  EDIT_STOP_MEDICATION_COMMAND = 52;
  DELETE_STOP_MEDICATION_COMMAND = 53;
  COMMIT_STOP_MEDICATION_COMMAND = 54;
  ENTER_IN_ERROR_STOP_MEDICATION_COMMAND = 55;

  ORIGINATE_UPDATE_GOAL_COMMAND = 56;
  EDIT_UPDATE_GOAL_COMMAND = 57;
  DELETE_UPDATE_GOAL_COMMAND = 58;
  COMMIT_UPDATE_GOAL_COMMAND = 59;
  ENTER_IN_ERROR_UPDATE_GOAL_COMMAND = 60;

  ORIGINATE_PERFORM_COMMAND = 61;
  EDIT_PERFORM_COMMAND = 62;
  DELETE_PERFORM_COMMAND = 63;
  COMMIT_PERFORM_COMMAND = 64;
  ENTER_IN_ERROR_PERFORM_COMMAND = 65;

  ORIGINATE_INSTRUCT_COMMAND = 66;
  EDIT_INSTRUCT_COMMAND = 67 ;
  DELETE_INSTRUCT_COMMAND = 68;
  COMMIT_INSTRUCT_COMMAND = 69;
  ENTER_IN_ERROR_INSTRUCT_COMMAND = 70;

  ORIGINATE_LAB_ORDER_COMMAND = 71;
  EDIT_LAB_ORDER_COMMAND = 72;
  DELETE_LAB_ORDER_COMMAND = 73;
  COMMIT_LAB_ORDER_COMMAND = 74;
  ENTER_IN_ERROR_LAB_ORDER_COMMAND = 75;
  SEND_LAB_ORDER_COMMAND = 1306;

  ORIGINATE_FAMILY_HISTORY_COMMAND = 76;
  EDIT_FAMILY_HISTORY_COMMAND = 77;
  DELETE_FAMILY_HISTORY_COMMAND = 78;
  COMMIT_FAMILY_HISTORY_COMMAND = 79;
  ENTER_IN_ERROR_FAMILY_HISTORY_COMMAND = 80;

  ORIGINATE_ALLERGY_COMMAND = 81;
  EDIT_ALLERGY_COMMAND = 82;
  DELETE_ALLERGY_COMMAND = 83;
  COMMIT_ALLERGY_COMMAND = 84;
  ENTER_IN_ERROR_ALLERGY_COMMAND = 85;

  ORIGINATE_REMOVE_ALLERGY_COMMAND = 86;
  EDIT_REMOVE_ALLERGY_COMMAND = 87;
  DELETE_REMOVE_ALLERGY_COMMAND = 88;
  COMMIT_REMOVE_ALLERGY_COMMAND = 89;
  ENTER_IN_ERROR_REMOVE_ALLERGY_COMMAND = 90;

  ORIGINATE_SURGICAL_HISTORY_COMMAND = 91;
  EDIT_SURGICAL_HISTORY_COMMAND = 92;
  DELETE_SURGICAL_HISTORY_COMMAND = 93;
  COMMIT_SURGICAL_HISTORY_COMMAND = 94;
  ENTER_IN_ERROR_SURGICAL_HISTORY_COMMAND = 95;

  CREATE_TASK = 100;
  UPDATE_TASK = 101;
  CREATE_TASK_COMMENT = 102;
  UPSERT_TASK_METADATA = 111;

  ORIGINATE_MEDICAL_HISTORY_COMMAND = 103;
  EDIT_MEDICAL_HISTORY_COMMAND = 104;
  DELETE_MEDICAL_HISTORY_COMMAND = 105;
  COMMIT_MEDICAL_HISTORY_COMMAND = 106;
  ENTER_IN_ERROR_MEDICAL_HISTORY_COMMAND = 107;

  ADD_OR_UPDATE_PROTOCOL_CARD = 110;

  ORIGINATE_TASK_COMMAND = 133;
  EDIT_TASK_COMMAND = 134;
  DELETE_TASK_COMMAND = 135;
  COMMIT_TASK_COMMAND = 136;
  ENTER_IN_ERROR_TASK_COMMAND = 137;

  ORIGINATE_REFILL_COMMAND = 113;
  EDIT_REFILL_COMMAND = 114;
  DELETE_REFILL_COMMAND = 115;
  COMMIT_REFILL_COMMAND = 116;
  ENTER_IN_ERROR_REFILL_COMMAND = 117;
  SEND_REFILL_COMMAND = 1308;
  REVIEW_REFILL_COMMAND = 1310;

  ORIGINATE_VITALS_COMMAND = 118;
  EDIT_VITALS_COMMAND = 119;
  DELETE_VITALS_COMMAND = 120;
  COMMIT_VITALS_COMMAND = 121;
  ENTER_IN_ERROR_VITALS_COMMAND = 122;

  ORIGINATE_UPDATE_DIAGNOSIS_COMMAND = 123;
  EDIT_UPDATE_DIAGNOSIS_COMMAND = 124;
  DELETE_UPDATE_DIAGNOSIS_COMMAND = 125;
  COMMIT_UPDATE_DIAGNOSIS_COMMAND = 126;
  ENTER_IN_ERROR_UPDATE_DIAGNOSIS_COMMAND = 127;

  ORIGINATE_CLOSE_GOAL_COMMAND = 128;
  EDIT_CLOSE_GOAL_COMMAND = 129;
  DELETE_CLOSE_GOAL_COMMAND = 130;
  COMMIT_CLOSE_GOAL_COMMAND = 131;
  ENTER_IN_ERROR_CLOSE_GOAL_COMMAND = 132;

  ORIGINATE_REFER_COMMAND = 139;
  EDIT_REFER_COMMAND = 140;
  DELETE_REFER_COMMAND = 141;
  COMMIT_REFER_COMMAND = 142;
  ENTER_IN_ERROR_REFER_COMMAND = 143;

  ORIGINATE_CHANGE_MEDICATION_COMMAND = 150;
  EDIT_CHANGE_MEDICATION_COMMAND = 151;
  DELETE_CHANGE_MEDICATION_COMMAND = 152;
  COMMIT_CHANGE_MEDICATION_COMMAND = 153;
  ENTER_IN_ERROR_CHANGE_MEDICATION_COMMAND = 154;

  CREATE_QUESTIONNAIRE_RESULT = 138;

  ANNOTATE_PATIENT_CHART_CONDITION_RESULTS = 200;
  ANNOTATE_PATIENT_CHART_DETECTED_ISSUE_RESULTS = 201;

  ANNOTATE_CLAIM_CONDITION_RESULTS = 300;

  SHOW_PATIENT_CHART_SUMMARY_SECTIONS = 400;

  SHOW_PATIENT_PROFILE_SECTIONS = 500;

  PATIENT_PROFILE__ADD_PHARMACY__POST_SEARCH_RESULTS = 501;

  SEND_SURESCRIPTS_ELIGIBILITY_REQUEST = 600;
  SEND_SURESCRIPTS_MEDICATION_HISTORY_REQUEST = 601;
  SEND_SURESCRIPTS_BENEFITS_REQUEST = 602;

  ORIGINATE_EXAM_COMMAND = 700;
  EDIT_EXAM_COMMAND = 701;
  DELETE_EXAM_COMMAND = 702;
  COMMIT_EXAM_COMMAND = 703;
  ENTER_IN_ERROR_EXAM_COMMAND = 704;

  ORIGINATE_ROS_COMMAND = 800;
  EDIT_ROS_COMMAND = 801;
  DELETE_ROS_COMMAND = 802;
  COMMIT_ROS_COMMAND = 803;
  ENTER_IN_ERROR_ROS_COMMAND = 804;

  ORIGINATE_STRUCTURED_ASSESSMENT_COMMAND = 900;
  EDIT_STRUCTURED_ASSESSMENT_COMMAND = 901;
  DELETE_STRUCTURED_ASSESSMENT_COMMAND = 902;
  COMMIT_STRUCTURED_ASSESSMENT_COMMAND = 903;
  ENTER_IN_ERROR_STRUCTURED_ASSESSMENT_COMMAND = 904;

  ORIGINATE_FOLLOW_UP_COMMAND = 905;
  EDIT_FOLLOW_UP_COMMAND = 906;
  DELETE_FOLLOW_UP_COMMAND = 907;
  COMMIT_FOLLOW_UP_COMMAND = 908;
  ENTER_IN_ERROR_FOLLOW_UP_COMMAND = 909;

  ORIGINATE_IMAGING_ORDER_COMMAND = 1100;
  EDIT_IMAGING_ORDER_COMMAND = 1101;
  DELETE_IMAGING_ORDER_COMMAND = 1102;
  COMMIT_IMAGING_ORDER_COMMAND = 1103;
  ENTER_IN_ERROR_IMAGING_ORDER_COMMAND = 1104;

  ORIGINATE_RESOLVE_CONDITION_COMMAND = 1200;
  EDIT_RESOLVE_CONDITION_COMMAND = 1201;
  DELETE_RESOLVE_CONDITION_COMMAND = 1202;
  COMMIT_RESOLVE_CONDITION_COMMAND = 1203;
  ENTER_IN_ERROR_RESOLVE_CONDITION_COMMAND = 1204;

  ORIGINATE_ADJUST_PRESCRIPTION_COMMAND = 1300;
  EDIT_ADJUST_PRESCRIPTION_COMMAND = 1301;
  DELETE_ADJUST_PRESCRIPTION_COMMAND = 1302;
  COMMIT_ADJUST_PRESCRIPTION_COMMAND = 1303;
  ENTER_IN_ERROR_ADJUST_PRESCRIPTION_COMMAND = 1304;
  SEND_ADJUST_PRESCRIPTION_COMMAND = 1307;
  REVIEW_ADJUST_PRESCRIPTION_COMMAND = 1311;

  ORIGINATE_CHART_SECTION_REVIEW_COMMAND = 1400;

  ORIGINATE_IMMUNIZATION_STATEMENT_COMMAND = 1500;
  EDIT_IMMUNIZATION_STATEMENT_COMMAND = 1501;
  DELETE_IMMUNIZATION_STATEMENT_COMMAND = 1502;
  COMMIT_IMMUNIZATION_STATEMENT_COMMAND = 1503;
  ENTER_IN_ERROR_IMMUNIZATION_STATEMENT_COMMAND = 1504;

  ORIGINATE_LAB_REVIEW_COMMAND = 1505;
  EDIT_LAB_REVIEW_COMMAND = 1506;
  DELETE_LAB_REVIEW_COMMAND = 1507;
  COMMIT_LAB_REVIEW_COMMAND = 1508;
  ENTER_IN_ERROR_LAB_REVIEW_COMMAND = 1509;

  ORIGINATE_IMAGING_REVIEW_COMMAND = 1510;
  EDIT_IMAGING_REVIEW_COMMAND = 1511;
  DELETE_IMAGING_REVIEW_COMMAND = 1512;
  COMMIT_IMAGING_REVIEW_COMMAND = 1513;
  ENTER_IN_ERROR_IMAGING_REVIEW_COMMAND = 1514;

  ORIGINATE_REFERRAL_REVIEW_COMMAND = 1515;
  EDIT_REFERRAL_REVIEW_COMMAND = 1516;
  DELETE_REFERRAL_REVIEW_COMMAND = 1517;
  COMMIT_REFERRAL_REVIEW_COMMAND = 1518;
  ENTER_IN_ERROR_REFERRAL_REVIEW_COMMAND = 1519;

  ORIGINATE_UNCATEGORIZED_DOCUMENT_REVIEW_COMMAND = 1520;
  EDIT_UNCATEGORIZED_DOCUMENT_REVIEW_COMMAND = 1521;
  DELETE_UNCATEGORIZED_DOCUMENT_REVIEW_COMMAND = 1522;
  COMMIT_UNCATEGORIZED_DOCUMENT_REVIEW_COMMAND = 1523;
  ENTER_IN_ERROR_UNCATEGORIZED_DOCUMENT_REVIEW_COMMAND = 1524;

  COMMAND_AVAILABLE_ACTIONS_RESULTS = 1600;
  COMMAND_VALIDATION_ERRORS = 1601;

  SHOW_ACTION_BUTTON = 1000;

  PATIENT_PORTAL__FORM_RESULT = 2000;
  PATIENT_PORTAL__APPOINTMENT_IS_CANCELABLE = 2001;
  PATIENT_PORTAL__APPOINTMENT_IS_RESCHEDULABLE = 2002;
  PATIENT_PORTAL__APPOINTMENT_SHOW_MEETING_LINK = 2003;
  PATIENT_PORTAL__SEND_INVITE = 2004;
  PATIENT_PORTAL__SEND_CONTACT_VERIFICATION = 2013;

  PATIENT_PORTAL__APPOINTMENTS__SLOTS__POST_SEARCH_RESULTS = 2005;
  PATIENT_PORTAL__APPOINTMENTS__FORM_APPOINTMENT_TYPES__PRE_SEARCH_RESULTS = 2006;
  PATIENT_PORTAL__APPOINTMENTS__FORM_APPOINTMENT_TYPES__POST_SEARCH_RESULTS = 2007;
  PATIENT_PORTAL__APPOINTMENTS__FORM_LOCATIONS__PRE_SEARCH_RESULTS = 2008;
  PATIENT_PORTAL__APPOINTMENTS__FORM_LOCATIONS__POST_SEARCH_RESULTS = 2009;
  PATIENT_PORTAL__APPOINTMENTS__FORM_PROVIDERS__PRE_SEARCH_RESULTS = 2010;
  PATIENT_PORTAL__APPOINTMENTS__FORM_PROVIDERS__POST_SEARCH_RESULTS = 2011;
  PATIENT_PORTAL__APPLICATION_CONFIGURATION = 2012;

  ADD_APPOINTMENT_LABEL = 2015;
  REMOVE_APPOINTMENT_LABEL = 2016;

  ADD_BILLING_LINE_ITEM = 2030;
  UPDATE_BILLING_LINE_ITEM = 2031;
  REMOVE_BILLING_LINE_ITEM = 2032;

  POST_CLAIM_PAYMENT = 2040;
  POST_CLAIMS_REMIT = 2041;

  MOVE_CLAIM_TO_QUEUE = 2060;
  ADD_CLAIM_LABEL = 2050;
  REMOVE_CLAIM_LABEL = 2051;

  UPDATE_CLAIM_LINE_ITEM = 2080;

  SHOW_PATIENT_PORTAL_MENU_ITEMS = 2100;
  PORTAL_WIDGET = 2101;

  LAUNCH_MODAL = 3000;

  SIMPLE_API_RESPONSE = 4000;
  SIMPLE_API_WEBSOCKET_ACCEPT = 4001;
  SIMPLE_API_WEBSOCKET_DENY = 4002;
  SIMPLE_API_WEBSOCKET_BROADCAST = 4003;

  UPDATE_USER = 5000;

  CREATE_NOTE = 6000;
  UPDATE_NOTE = 6013;
  PUSH_NOTE_CHARGES = 5500;
  FAX_NOTE = 6019;
  LOCK_NOTE = 6025;
  UNLOCK_NOTE = 6026;
  SIGN_NOTE = 6027;
  CHECK_IN_NOTE = 6028;
  NO_SHOW_NOTE = 6029;

  CREATE_APPOINTMENT = 6001;
  UPDATE_APPOINTMENT = 6014;
  RESCHEDULE_APPOINTMENT = 6022;
  CANCEL_APPOINTMENT = 6015;
  CREATE_SCHEDULE_EVENT = 6002;
  UPDATE_SCHEDULE_EVENT = 6016;
  DELETE_SCHEDULE_EVENT = 6017;
  RESCHEDULE_SCHEDULE_EVENT = 6023;

  CREATE_PATIENT = 6003;
  UPDATE_PATIENT = 6008;

  CREATE_MESSAGE = 6004;
  SEND_MESSAGE = 6005;
  CREATE_AND_SEND_MESSAGE = 6006;
  EDIT_MESSAGE = 6007;

  PATIENT_METADATA__CREATE_ADDITIONAL_FIELDS = 6010;
  UPSERT_PATIENT_METADATA = 6011;
  CREATE_PATIENT_EXTERNAL_IDENTIFIER = 6012;
  CREATE_PATIENT_PREFERRED_PHARMACIES = 6018;
  CREATE_COMPOUND_MEDICATION = 6020;
  UPDATE_COMPOUND_MEDICATION = 6021;

  CREATE_OBSERVATION = 6031;
  UPDATE_OBSERVATION = 6032;

  PATIENT_CHART__GROUP_ITEMS = 6030;

  APPOINTMENT__FORM__PROVIDERS__PRE_SEARCH_RESULTS = 6040;
  APPOINTMENT__FORM__LOCATIONS__PRE_SEARCH_RESULTS = 6041;
  APPOINTMENT__FORM__VISIT_TYPES__PRE_SEARCH_RESULTS = 6042;
  APPOINTMENT__FORM__DURATIONS__PRE_SEARCH_RESULTS = 6043;
  APPOINTMENT__FORM__REASON_FOR_VISIT__PRE_SEARCH_RESULTS = 6044;

  APPOINTMENT__FORM__PROVIDERS__POST_SEARCH_RESULTS = 6046;
  APPOINTMENT__FORM__LOCATIONS__POST_SEARCH_RESULTS = 6047;
  APPOINTMENT__FORM__VISIT_TYPES__POST_SEARCH_RESULTS = 6048;
  APPOINTMENT__FORM__DURATIONS__POST_SEARCH_RESULTS = 6049;
  APPOINTMENT__FORM__REASON_FOR_VISIT__POST_SEARCH_RESULTS = 6050;

  APPOINTMENT__FORM__CREATE_ADDITIONAL_FIELDS = 6051;

  UPSERT_APPOINTMENT_METADATA = 6052;

  APPOINTMENT__SLOTS__POST_SEARCH_RESULTS = 6053;

  SHOW_PANEL_SECTIONS = 6100;

  REDIRECT_CONTEXT = 6200;

  REVENUE__PAYMENT_PROCESSOR__METADATA = 7001;
  REVENUE__PAYMENT_PROCESSOR__FORM = 7002;
  REVENUE__PAYMENT_PROCESSOR__CREDIT_CARD_TRANSACTION = 7003;
  REVENUE__PAYMENT_PROCESSOR__PAYMENT_METHOD = 7004;
  REVENUE__PAYMENT_PROCESSOR__PAYMENT_METHOD__ADD_RESPONSE = 7005;
  REVENUE__PAYMENT_PROCESSOR__PAYMENT_METHOD__REMOVE_RESPONSE = 7006;

  GENERATE_FULL_CHART_PDF = 6101;

  BATCH_ORIGINATE_COMMANDS = 6024;

  CALENDAR__CREATE = 8001;
  CALENDAR__EVENT__CREATE = 8002;
  CALENDAR__EVENT__UPDATE = 8003;
  CALENDAR__EVENT__DELETE = 8004;

}

message Effect {
  EffectType type = 1;
  string payload = 2;
  string plugin_name = 3;
  string classname = 4;
  string handler_name = 5;
  string actor = 6;
  string source = 7;
  //Oneof effect_payload {
  //  ...
  //}
}
